@@ -8,6 +8,12 @@ use warnings;
 
 our $unique_counter = 0;
 
+##################################################
+sub reset {
+##################################################
+    $unique_counter = 0;
+}
+
 ##################################################
 sub unique_name {
 ##################################################
